@@ -1,21 +1,40 @@
 import os
 import pathlib
 
-from typing import Any, Type, Tuple, Dict, List, Union, Optional
-from pydantic import Field, validator
-from pydantic.networks import AnyUrl
-from pydantic import BaseModel as _BaseModel
-from pydantic import BaseSettings as _BaseSettings
-from lazyops.types.formatting import to_snake_case, to_graphql_format
+from typing import Any, Type, Tuple, Dict, List, Union, Optional, Callable, TYPE_CHECKING
+from lazyops.types.formatting import to_camel_case, to_snake_case, to_graphql_format
 from lazyops.types.classprops import classproperty, lazyproperty
 from lazyops.utils.serialization import Json
 
+from pydantic import Field
+from pydantic.networks import AnyUrl
+from lazyops.imports._pydantic import BaseSettings as _BaseSettings
+from lazyops.imports._pydantic import BaseModel as _BaseModel
+from lazyops.imports._pydantic import (
+    validator, 
+    root_validator, 
+    pre_root_validator, 
+    get_pyd_dict, 
+    get_pyd_fields, 
+    get_pyd_field_names,
+    get_pyd_fields_dict,
+    get_pyd_schema,
+    pyd_parse_obj,
+    ConfigDict,
+    PYD_VERSION,
+)
+
+"""
+Migration to pydantic v2 with backwards compatibility
+"""
+
 class BaseSettings(_BaseSettings):
 
     class Config:
         env_prefix: str = ""
         case_sensitive: bool = False
 
+
     def update_config(self, **kwargs):
         """
         Update the config for the other settings
@@ -24,7 +43,7 @@ class BaseSettings(_BaseSettings):
             if not hasattr(self, k): continue
             if isinstance(getattr(self, k), pathlib.Path):
                 setattr(self, k, pathlib.Path(v))
-            elif isinstance(getattr(self, k), BaseSettings):
+            elif isinstance(getattr(self, k), self.__class__):
                 val = getattr(self, k)
                 if hasattr(val, 'update_config'):
                     val.update_config(**v)
@@ -38,26 +57,58 @@ class BaseSettings(_BaseSettings):
         """
         Update the Env variables for the current session
         """
-        data = self.dict(exclude_none=True)
+        data = get_pyd_dict(self, exclude_none=True)
         for k, v in data.items():
             if isinstance(v, BaseSettings):
                 v.set_env()
             else:
                 os.environ[self.Config.env_prefix + k.upper()] = str(v)
     
-    
+
+class ProxySettings:
+    def __init__(
+        self,
+        settings_cls: Optional[Type[BaseSettings]] = None,
+        settings_getter: Optional[Union[Callable, str]] = None,
+    ):
+        assert settings_cls or settings_getter, "Either settings_cls or settings_getter must be provided"
+        self._settings_cls = settings_cls
+        self._settings_getter = settings_getter
+        if self._settings_getter and isinstance(self._settings_getter, str):
+            from lazyops.utils.helpers import import_string
+            self._settings_getter = import_string(self._settings_getter)
+        self._settings = None
+
+    def __getattr__(self, name):
+        if self._settings is None:
+            if self._settings_getter:
+                self._settings = self._settings_getter()
+            elif self._settings_cls:
+                self._settings = self._settings_cls()
+        return getattr(self._settings, name)
 
 
 class BaseModel(_BaseModel):
-    class Config:
-        extra = 'allow'
-        arbitrary_types_allowed = True
-        alias_generator = to_snake_case
+
+    if PYD_VERSION == 1:
+        class Config:
+            extra = 'allow'
+            arbitrary_types_allowed = True
+            alias_generator = to_snake_case
+    else:
+        model_config = ConfigDict(extra = 'allow', arbitrary_types_allowed = True)
         
+                
     def get(self, name, default: Any = None):
+        """
+        Get an attribute from the model
+        """
         return getattr(self, name, default)
     
     def update(self, **kwargs):
+        """
+        Update the model attributes
+        """
         for k, v in kwargs.items():
             if not hasattr(self, k): continue
             setattr(self, k, v)
@@ -72,29 +123,45 @@ class BaseModel(_BaseModel):
         Extracts the resource from the kwargs and returns the resource 
         and the remaining kwargs
         """
-        resource_fields = [field.name for field in cls.__fields__.values()]
+        resource_fields = get_pyd_field_names(cls)
+        # resource_fields = [field.name for field in cls.__fields__.values()]
+
         resource_kwargs = {k: v for k, v in kwargs.items() if k in resource_fields}
         return_kwargs = {k: v for k, v in kwargs.items() if k not in resource_fields}
-        resource_obj = cls.parse_obj(resource_kwargs)
+        resource_obj = pyd_parse_obj(cls, resource_kwargs)
+        # resource_obj = cls.parse_obj(resource_kwargs)
         return resource_obj, return_kwargs
     
     @classmethod
     def create_many(cls, data: List[Dict]) -> List['BaseModel']:
-        return [cls.parse_obj(d) for d in data]
+        """
+        Create a list of resources from a list of dicts
+        """
+        return [pyd_parse_obj(cls, d) for d in data]
+        # return [cls.parse_obj(d) for d in data]
     
+
     @classproperty
-    def model_fields(cls) -> List[str]:
-        return [field.name for field in cls.__fields__.values()]
-    
-    def get_model_fields(self) -> List[str]:
-        return [field.name for field in self.__fields__.values()]
+    def model_field_names(cls) -> List[str]:
+        """
+        Returns the model fields names
+        """
+        return get_pyd_field_names(cls)
+        # return [field.name for field in cls.__fields__.values()]
+        
+    def get_model_field_names(self) -> List[str]:
+        """
+        Get the model fields
+        """
+        return get_pyd_field_names(self.__class__)
+        # return [field.name for field in self.__fields__.values()]
 
     def replace(self, obj: Type['BaseModel']):
         """Replace current attributes with `obj` attributes."""
-        for field in obj.model_fields:
+        for field in obj.get_model_field_names():
             if hasattr(self, field):
                 setattr(self, field, getattr(obj, field))
-
+    
     def graphql(
         self,
         *,
@@ -109,14 +176,46 @@ class BaseModel(_BaseModel):
         """
         Return the data in `graphql` format
         """
-        data = self.dict(
+        data = get_pyd_dict(
             include = include, exclude = exclude, \
             by_alias = by_alias, skip_defaults = skip_defaults, \
             exclude_unset = exclude_unset, exclude_defaults = exclude_defaults, \
             exclude_none = exclude_none
         )
+
+        # data = self.dict(
+        #     include = include, exclude = exclude, \
+        #     by_alias = by_alias, skip_defaults = skip_defaults, \
+        #     exclude_unset = exclude_unset, exclude_defaults = exclude_defaults, \
+        #     exclude_none = exclude_none
+        # )
         return to_graphql_format(data)
 
+    @classmethod
+    def parse_obj(
+        cls,
+        obj: Any,
+        strict: Optional[bool] = False,
+        from_attributes: Optional[bool] = True,
+        **kwargs
+    ) -> 'BaseModel':
+        """
+        Parses an object into the resource
+        """
+        return pyd_parse_obj(cls, obj, strict = strict, from_attributes = from_attributes, **kwargs)
+    
+    def dict(self, **kwargs):
+        """
+        Returns the dict representation of the response
+        """
+        return get_pyd_dict(self, **kwargs)
+
+    def schema(self, **kwargs):
+        """
+        Returns the dict representation of the response
+        """
+        return get_pyd_schema(self, **kwargs)
+
 
 
 class Schema(BaseModel):
@@ -124,7 +223,13 @@ class Schema(BaseModel):
     class Config:
         extra = 'allow'
         arbitrary_types_allowed = True
-        json_dumps = Json.dumps
+        if PYD_VERSION == 1:
+            json_dumps = Json.dumps
+        # alias_generator = to_camel_case
+
+    # @lazyproperty
+    # def schema_fields(self) -> List[str]:
+    #     return [field.name for field in self.__fields__.values()]
 
     def get(self, name, default: Any = None):
         return getattr(self, name, default)
