@@ -14,24 +14,34 @@ from lazyops.utils.serialization import (
     ObjectEncoder, ObjectDecoder,
     Json,
 )
+from lazyops.utils.lazy import (
+    import_string, 
+    lazy_import, 
+    is_coro_func,
+    import_function,
+    validate_callable,
+    fetch_property,
+    extract_base_model_kws,
+
+)
 from lazyops.utils.helpers import (
     timer,
     timed,
     merge_dicts,
-    is_coro_func,
+    
     exponential_backoff,
     retryable,
     build_batches,
     get_batches_from_generator,
     split_into_batches,
+    split_into_batches_with_index,
 
-    import_function,
     create_timestamp,
     create_unique_id,
     create_secret,
-    fetch_property,
 
     suppress,
     timed_cache,
     fail_after,
+    create_background_task,
 )   
