@@ -3,6 +3,8 @@ Base Import Handler
 """
 import typing
 import functools
+import pathlib
+import importlib.util
 from lazyops.utils.logs import default_logger as logger
 from lazyops.utils.lazylib import LazyLib
 from lazyops.utils.helpers import is_coro_func
@@ -69,4 +71,5 @@ def require_missing_wrapper(
             resolver(**resolver_kwargs)
             return func(*args, **kwargs)
 
-    return wrapper
\ No newline at end of file
+    return wrapper
+
